@@ -1,4 +1,4 @@
-from typing import List
+from typing import List, Union
 
 from pyspark.sql import DataFrame
 
@@ -8,15 +8,16 @@ from atc.etl import TransformerNC
 class DropColumnsTransformer(TransformerNC):
     def __init__(
         self,
+        *,
         columnList: List[str],
-        dataset_input_key: str = None,
+        dataset_input_keys: Union[str, List[str]] = None,
         dataset_output_key: str = None,
     ):
         super().__init__(
-            dataset_input_key=dataset_input_key, dataset_output_key=dataset_output_key
+            dataset_input_keys=dataset_input_keys,
+            dataset_output_key=dataset_output_key,
         )
         self.columnList = columnList
 
     def process(self, df: DataFrame) -> DataFrame:
-        df = df.drop(*self.columnList)
-        return df
+        return df.drop(*self.columnList)
